/* GAttributeTest.c generated by valac 0.34.6, the Vala compiler
 * generated from GAttributeTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <gee.h>


#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GATTRIBUTE_TEST (gattribute_test_get_type ())
#define GATTRIBUTE_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GATTRIBUTE_TEST, GAttributeTest))
#define GATTRIBUTE_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GATTRIBUTE_TEST, GAttributeTestClass))
#define IS_GATTRIBUTE_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GATTRIBUTE_TEST))
#define IS_GATTRIBUTE_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GATTRIBUTE_TEST))
#define GATTRIBUTE_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GATTRIBUTE_TEST, GAttributeTestClass))

typedef struct _GAttributeTest GAttributeTest;
typedef struct _GAttributeTestClass GAttributeTestClass;
typedef struct _GAttributeTestPrivate GAttributeTestPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GAttributeTest {
	GXmlTest parent_instance;
	GAttributeTestPrivate * priv;
};

struct _GAttributeTestClass {
	GXmlTestClass parent_class;
};


static gpointer gattribute_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType gattribute_test_get_type (void) G_GNUC_CONST;
enum  {
	GATTRIBUTE_TEST_DUMMY_PROPERTY
};
void gattribute_test_add_tests (void);
static void __lambda187_ (void);
static void ___lambda187__gtest_func (void);
static void __lambda188_ (void);
static void ___lambda188__gtest_func (void);
static void __lambda189_ (void);
static void ___lambda189__gtest_func (void);
static void __lambda190_ (void);
static void ___lambda190__gtest_func (void);
GAttributeTest* gattribute_test_new (void);
GAttributeTest* gattribute_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);


static void __lambda187_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGAttribute* attr = NULL;
		GXmlNode* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GeeBidirList* _tmp4_ = NULL;
		GeeBidirList* _tmp5_ = NULL;
		GeeBidirList* _tmp6_ = NULL;
		gpointer _tmp7_ = NULL;
		GXmlNode* _tmp8_ = NULL;
		GeeMap* _tmp9_ = NULL;
		GeeMap* _tmp10_ = NULL;
		GeeMap* _tmp11_ = NULL;
		gpointer _tmp12_ = NULL;
		GXmlGAttribute* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		GXmlNode* _tmp20_ = NULL;
		GXmlNode* _tmp21_ = NULL;
		GXmlNode* _tmp22_ = NULL;
		GeeBidirList* _tmp23_ = NULL;
		GeeBidirList* _tmp24_ = NULL;
		GeeBidirList* _tmp25_ = NULL;
		gpointer _tmp26_ = NULL;
		GXmlNode* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		GXmlGAttribute* shell = NULL;
		GXmlNode* _tmp30_ = NULL;
		GXmlNode* _tmp31_ = NULL;
		GXmlNode* _tmp32_ = NULL;
		GeeBidirList* _tmp33_ = NULL;
		GeeBidirList* _tmp34_ = NULL;
		GeeBidirList* _tmp35_ = NULL;
		gpointer _tmp36_ = NULL;
		GXmlNode* _tmp37_ = NULL;
		GeeMap* _tmp38_ = NULL;
		GeeMap* _tmp39_ = NULL;
		GeeMap* _tmp40_ = NULL;
		gpointer _tmp41_ = NULL;
		GXmlGAttribute* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
		GXmlNode* _tmp49_ = NULL;
		GXmlNode* _tmp50_ = NULL;
		GXmlNode* _tmp51_ = NULL;
		GeeBidirList* _tmp52_ = NULL;
		GeeBidirList* _tmp53_ = NULL;
		GeeBidirList* _tmp54_ = NULL;
		gpointer _tmp55_ = NULL;
		GXmlNode* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		GXmlNode* _tmp59_ = NULL;
		GXmlNode* _tmp60_ = NULL;
		GXmlNode* _tmp61_ = NULL;
		GeeBidirList* _tmp62_ = NULL;
		GeeBidirList* _tmp63_ = NULL;
		GeeBidirList* _tmp64_ = NULL;
		gpointer _tmp65_ = NULL;
		GXmlNode* _tmp66_ = NULL;
		gchar* _tmp67_ = NULL;
		gchar* _tmp68_ = NULL;
#line 30 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<Wands xmlns:wands=\"http://mom.co.uk/wands\"><Wand price=\"43.56\" wa" \
"nds:core=\"dragon heart cord\" wands:shell=\"oak\"/></Wands>", 0, &_inner_error_);
#line 30 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		doc = _tmp0_;
#line 30 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 192 "GAttributeTest.c"
			goto __catch173_g_error;
		}
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp1_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp2_ = _tmp1_;
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp3_ = _tmp2_;
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp4_ = gxml_node_get_children_nodes (_tmp3_);
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp5_ = _tmp4_;
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp6_ = _tmp5_;
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp7_ = gee_list_get ((GeeList*) _tmp6_, 0);
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp8_ = (GXmlNode*) _tmp7_;
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp9_ = gxml_node_get_attrs (_tmp8_);
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp10_ = _tmp9_;
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp11_ = _tmp10_;
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp12_ = gee_map_get (_tmp11_, "price");
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp13_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlNode*) _tmp12_, GXML_TYPE_GATTRIBUTE, GXmlGAttribute);
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp11_);
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp8_);
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp6_);
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp3_);
#line 31 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		attr = _tmp13_;
#line 32 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (attr != NULL, "attr != null");
#line 33 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp14_ = gxml_dom_attr_get_name ((GXmlDomAttr*) attr);
#line 33 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp15_ = _tmp14_;
#line 33 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp16_ = _tmp15_;
#line 33 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "price") == 0, "attr.name == \"price\"");
#line 33 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp16_);
#line 34 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp17_ = gxml_dom_attr_get_value ((GXmlDomAttr*) attr);
#line 34 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp18_ = _tmp17_;
#line 34 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp19_ = _tmp18_;
#line 34 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp19_, "43.56") == 0, "attr.value == \"43.56\"");
#line 34 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp19_);
#line 35 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		gxml_dom_attr_set_value ((GXmlDomAttr*) attr, "56.1");
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp20_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp21_ = _tmp20_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp22_ = _tmp21_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp23_ = gxml_node_get_children_nodes (_tmp22_);
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp24_ = _tmp23_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp25_ = _tmp24_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp26_ = gee_list_get ((GeeList*) _tmp25_, 0);
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp27_ = (GXmlNode*) _tmp26_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp28_ = gxml_node_to_string (_tmp27_);
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp29_ = _tmp28_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, "<Wand price=\"56.1\" wands:core=\"dragon heart cord\" wands:shell=\"oa" \
"k\"/>") == 0, "doc.root.children_nodes[0].to_string () == \"<Wand price=\\\"56.1\\\" wands:core=\\\"dragon heart cord\\\" wands:shell=\\\"oak\\\"/>\"");
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp29_);
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp27_);
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp25_);
#line 36 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp22_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp30_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp31_ = _tmp30_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp32_ = _tmp31_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp33_ = gxml_node_get_children_nodes (_tmp32_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp34_ = _tmp33_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp35_ = _tmp34_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp36_ = gee_list_get ((GeeList*) _tmp35_, 0);
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp37_ = (GXmlNode*) _tmp36_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp38_ = gxml_node_get_attrs (_tmp37_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp39_ = _tmp38_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp40_ = _tmp39_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp41_ = gee_map_get (_tmp40_, "shell");
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp42_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlNode*) _tmp41_, GXML_TYPE_GATTRIBUTE, GXmlGAttribute);
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp40_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp37_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp35_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp32_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		shell = _tmp42_;
#line 39 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (shell != NULL, "shell != null");
#line 40 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp43_ = gxml_dom_attr_get_name ((GXmlDomAttr*) shell);
#line 40 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp44_ = _tmp43_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp45_ = _tmp44_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp45_, "shell") == 0, "shell.name == \"shell\"");
#line 40 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp45_);
#line 41 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp46_ = gxml_dom_attr_get_value ((GXmlDomAttr*) shell);
#line 41 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp47_ = _tmp46_;
#line 41 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp48_ = _tmp47_;
#line 41 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "oak") == 0, "shell.value == \"oak\"");
#line 41 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp48_);
#line 42 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		gxml_dom_attr_set_value ((GXmlDomAttr*) shell, "Bad!?");
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp49_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp50_ = _tmp49_;
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp51_ = _tmp50_;
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp52_ = gxml_node_get_children_nodes (_tmp51_);
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp53_ = _tmp52_;
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp54_ = _tmp53_;
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp55_ = gee_list_get ((GeeList*) _tmp54_, 0);
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp56_ = (GXmlNode*) _tmp55_;
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp57_ = gxml_node_to_string (_tmp56_);
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp58_ = _tmp57_;
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_test_message ("%s", _tmp58_);
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp58_);
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp56_);
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp54_);
#line 43 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp51_);
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp59_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp60_ = _tmp59_;
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp61_ = _tmp60_;
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp62_ = gxml_node_get_children_nodes (_tmp61_);
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp63_ = _tmp62_;
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp64_ = _tmp63_;
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp65_ = gee_list_get ((GeeList*) _tmp64_, 0);
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp66_ = (GXmlNode*) _tmp65_;
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp67_ = gxml_node_to_string (_tmp66_);
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp68_ = _tmp67_;
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp68_, "<Wand price=\"56.1\" wands:core=\"dragon heart cord\" wands:shell=\"Ba" \
"d!?\"/>") == 0, "doc.root.children_nodes[0].to_string () == \"<Wand price=\\\"56.1\\\" wands:core=\\\"dragon heart cord\\\" wands:shell=\\\"Bad!?\\\"/>\"");
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp68_);
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp66_);
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp64_);
#line 44 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp61_);
#line 29 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (shell);
#line 29 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (attr);
#line 29 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (doc);
#line 411 "GAttributeTest.c"
	}
	goto __finally173;
	__catch173_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp69_ = NULL;
		gchar* _tmp70_ = NULL;
		gchar* _tmp71_ = NULL;
#line 29 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		e = _inner_error_;
#line 29 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_inner_error_ = NULL;
#line 46 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp69_ = e->message;
#line 46 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp70_ = g_strconcat ("ERROR: ", _tmp69_, NULL);
#line 46 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp71_ = _tmp70_;
#line 46 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_test_message ("%s", _tmp71_);
#line 46 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp71_);
#line 47 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_assert_not_reached ();
#line 29 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_error_free0 (e);
#line 438 "GAttributeTest.c"
	}
	__finally173:
#line 29 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 29 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 29 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_clear_error (&_inner_error_);
#line 29 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		return;
#line 449 "GAttributeTest.c"
	}
}


static void ___lambda187__gtest_func (void) {
#line 28 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	__lambda187_ ();
#line 457 "GAttributeTest.c"
}


static void __lambda188_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlNode* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GXmlGNode* root = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlGElement* node = NULL;
		GeeBidirList* _tmp6_ = NULL;
		GeeBidirList* _tmp7_ = NULL;
		GeeBidirList* _tmp8_ = NULL;
		gpointer _tmp9_ = NULL;
		GXmlGElement* _tmp10_ = NULL;
		GXmlGAttribute* core = NULL;
		GeeMap* _tmp11_ = NULL;
		GeeMap* _tmp12_ = NULL;
		GeeMap* _tmp13_ = NULL;
		gpointer _tmp14_ = NULL;
		GXmlGAttribute* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		GXmlNamespace* _tmp19_ = NULL;
		GXmlNamespace* _tmp20_ = NULL;
		GXmlNamespace* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		GXmlNamespace* _tmp25_ = NULL;
		GXmlNamespace* _tmp26_ = NULL;
		GXmlNamespace* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		GeeList* _tmp31_ = NULL;
		GeeList* _tmp32_ = NULL;
		GeeList* _tmp33_ = NULL;
		GeeList* _tmp34_ = NULL;
		GeeList* _tmp35_ = NULL;
		GeeList* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		gint _tmp38_ = 0;
		GeeList* _tmp39_ = NULL;
		GeeList* _tmp40_ = NULL;
		GeeList* _tmp41_ = NULL;
		gpointer _tmp42_ = NULL;
		GXmlNamespace* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
		GXmlGAttribute* shell = NULL;
		GeeMap* _tmp50_ = NULL;
		GeeMap* _tmp51_ = NULL;
		GeeMap* _tmp52_ = NULL;
		gpointer _tmp53_ = NULL;
		GXmlGAttribute* _tmp54_ = NULL;
		gchar* _tmp55_ = NULL;
		gchar* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		GeeList* _tmp58_ = NULL;
		GeeList* _tmp59_ = NULL;
		GeeList* _tmp60_ = NULL;
		GeeList* _tmp61_ = NULL;
		GeeList* _tmp62_ = NULL;
		GeeList* _tmp63_ = NULL;
		gint _tmp64_ = 0;
		gint _tmp65_ = 0;
		GeeList* _tmp66_ = NULL;
		GeeList* _tmp67_ = NULL;
		GeeList* _tmp68_ = NULL;
		gpointer _tmp69_ = NULL;
		GXmlNamespace* _tmp70_ = NULL;
		gchar* _tmp71_ = NULL;
		gchar* _tmp72_ = NULL;
		gchar* _tmp73_ = NULL;
		gchar* _tmp74_ = NULL;
		gchar* _tmp75_ = NULL;
		gchar* _tmp76_ = NULL;
		GXmlGAttribute* price = NULL;
		GeeMap* _tmp77_ = NULL;
		GeeMap* _tmp78_ = NULL;
		GeeMap* _tmp79_ = NULL;
		gpointer _tmp80_ = NULL;
		GXmlGAttribute* _tmp81_ = NULL;
		gchar* _tmp82_ = NULL;
		gchar* _tmp83_ = NULL;
		gchar* _tmp84_ = NULL;
		GeeList* _tmp85_ = NULL;
		GeeList* _tmp86_ = NULL;
		GeeList* _tmp87_ = NULL;
		GeeList* _tmp88_ = NULL;
		GeeList* _tmp89_ = NULL;
		GeeList* _tmp90_ = NULL;
		gint _tmp91_ = 0;
		gint _tmp92_ = 0;
#line 52 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<Wands xmlns:wands=\"http://mom.co.uk/wands\"><Wand price=\"43.56\" wa" \
"nds:core=\"dragon heart cord\" wands:shell=\"oak\"/></Wands>", 0, &_inner_error_);
#line 52 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		doc = _tmp0_;
#line 52 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 569 "GAttributeTest.c"
			goto __catch174_g_error;
		}
#line 53 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp1_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 53 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp2_ = _tmp1_;
#line 53 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp3_ = _tmp2_;
#line 53 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.root != null");
#line 53 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp3_);
#line 54 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 54 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp5_ = _tmp4_;
#line 54 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GXML_TYPE_GNODE, GXmlGNode);
#line 55 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp6_ = gxml_gnode_get_children_nodes (root);
#line 55 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp7_ = _tmp6_;
#line 55 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp8_ = _tmp7_;
#line 55 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp9_ = gee_list_get ((GeeList*) _tmp8_, 0);
#line 55 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlNode*) _tmp9_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 55 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp8_);
#line 55 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		node = _tmp10_;
#line 57 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp11_ = gxml_gnode_get_attrs ((GXmlGNode*) node);
#line 57 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp12_ = _tmp11_;
#line 57 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp13_ = _tmp12_;
#line 57 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp14_ = gee_map_get (_tmp13_, "core");
#line 57 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp15_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlNode*) _tmp14_, GXML_TYPE_GATTRIBUTE, GXmlGAttribute);
#line 57 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp13_);
#line 57 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		core = _tmp15_;
#line 58 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (core != NULL, "core != null");
#line 59 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp16_ = gxml_dom_attr_get_name ((GXmlDomAttr*) core);
#line 59 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp17_ = _tmp16_;
#line 59 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp18_ = _tmp17_;
#line 59 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp18_, "core") == 0, "core.name == \"core\"");
#line 59 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp18_);
#line 60 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp19_ = gxml_attribute_get_namespace ((GXmlAttribute*) core);
#line 60 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp20_ = _tmp19_;
#line 60 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp21_ = _tmp20_;
#line 60 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp22_ = gxml_namespace_get_prefix (_tmp21_);
#line 60 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp23_ = _tmp22_;
#line 60 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp24_ = _tmp23_;
#line 60 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "wands") == 0, "core.namespace.prefix == \"wands\"");
#line 60 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp24_);
#line 60 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp21_);
#line 61 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp25_ = gxml_attribute_get_namespace ((GXmlAttribute*) core);
#line 61 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp26_ = _tmp25_;
#line 61 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp27_ = _tmp26_;
#line 61 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp28_ = gxml_namespace_get_uri (_tmp27_);
#line 61 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp29_ = _tmp28_;
#line 61 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp30_ = _tmp29_;
#line 61 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp30_, "http://mom.co.uk/wands") == 0, "core.namespace.uri == \"http://mom.co.uk/wands\"");
#line 61 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp30_);
#line 61 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp27_);
#line 62 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp31_ = gxml_gnode_get_namespaces ((GXmlGNode*) core);
#line 62 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp32_ = _tmp31_;
#line 62 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp33_ = _tmp32_;
#line 62 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (_tmp33_ != NULL, "core.namespaces != null");
#line 62 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp33_);
#line 63 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp34_ = gxml_gnode_get_namespaces ((GXmlGNode*) core);
#line 63 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp35_ = _tmp34_;
#line 63 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp36_ = _tmp35_;
#line 63 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp37_ = gee_collection_get_size ((GeeCollection*) _tmp36_);
#line 63 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp38_ = _tmp37_;
#line 63 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (_tmp38_ == 1, "core.namespaces.size == 1");
#line 63 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp36_);
#line 64 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp39_ = gxml_gnode_get_namespaces ((GXmlGNode*) core);
#line 64 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp40_ = _tmp39_;
#line 64 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp41_ = _tmp40_;
#line 64 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp42_ = gee_list_get (_tmp41_, 0);
#line 64 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp43_ = (GXmlNamespace*) _tmp42_;
#line 64 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp44_ = gxml_namespace_get_uri (_tmp43_);
#line 64 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp45_ = _tmp44_;
#line 64 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp46_ = _tmp45_;
#line 64 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "http://mom.co.uk/wands") == 0, "core.namespaces[0].uri == \"http://mom.co.uk/wands\"");
#line 64 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp46_);
#line 64 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp43_);
#line 64 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp41_);
#line 65 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp47_ = gxml_attribute_get_prefix ((GXmlAttribute*) core);
#line 65 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp48_ = _tmp47_;
#line 65 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp49_ = _tmp48_;
#line 65 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp49_, "wands") == 0, "core.prefix == \"wands\"");
#line 65 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp49_);
#line 66 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp50_ = gxml_gnode_get_attrs ((GXmlGNode*) node);
#line 66 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp51_ = _tmp50_;
#line 66 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp52_ = _tmp51_;
#line 66 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp53_ = gee_map_get (_tmp52_, "shell");
#line 66 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp54_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlNode*) _tmp53_, GXML_TYPE_GATTRIBUTE, GXmlGAttribute);
#line 66 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp52_);
#line 66 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		shell = _tmp54_;
#line 67 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (shell != NULL, "shell != null");
#line 68 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp55_ = gxml_dom_attr_get_name ((GXmlDomAttr*) shell);
#line 68 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp56_ = _tmp55_;
#line 68 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp57_ = _tmp56_;
#line 68 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp57_, "shell") == 0, "shell.name == \"shell\"");
#line 68 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp57_);
#line 69 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp58_ = gxml_gnode_get_namespaces ((GXmlGNode*) shell);
#line 69 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp59_ = _tmp58_;
#line 69 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp60_ = _tmp59_;
#line 69 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (_tmp60_ != NULL, "shell.namespaces != null");
#line 69 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp60_);
#line 70 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp61_ = gxml_gnode_get_namespaces ((GXmlGNode*) shell);
#line 70 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp62_ = _tmp61_;
#line 70 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp63_ = _tmp62_;
#line 70 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp64_ = gee_collection_get_size ((GeeCollection*) _tmp63_);
#line 70 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp65_ = _tmp64_;
#line 70 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (_tmp65_ == 1, "shell.namespaces.size == 1");
#line 70 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp63_);
#line 71 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp66_ = gxml_gnode_get_namespaces ((GXmlGNode*) shell);
#line 71 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp67_ = _tmp66_;
#line 71 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp68_ = _tmp67_;
#line 71 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp69_ = gee_list_get (_tmp68_, 0);
#line 71 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp70_ = (GXmlNamespace*) _tmp69_;
#line 71 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp71_ = gxml_namespace_get_uri (_tmp70_);
#line 71 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp72_ = _tmp71_;
#line 71 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp73_ = _tmp72_;
#line 71 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp73_, "http://mom.co.uk/wands") == 0, "shell.namespaces[0].uri == \"http://mom.co.uk/wands\"");
#line 71 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp73_);
#line 71 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp70_);
#line 71 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp68_);
#line 72 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp74_ = gxml_attribute_get_prefix ((GXmlAttribute*) shell);
#line 72 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp75_ = _tmp74_;
#line 72 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp76_ = _tmp75_;
#line 72 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp76_, "wands") == 0, "shell.prefix == \"wands\"");
#line 72 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp76_);
#line 73 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp77_ = gxml_gnode_get_attrs ((GXmlGNode*) node);
#line 73 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp78_ = _tmp77_;
#line 73 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp79_ = _tmp78_;
#line 73 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp80_ = gee_map_get (_tmp79_, "price");
#line 73 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp81_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlNode*) _tmp80_, GXML_TYPE_GATTRIBUTE, GXmlGAttribute);
#line 73 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp79_);
#line 73 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		price = _tmp81_;
#line 74 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (price != NULL, "price != null");
#line 75 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp82_ = gxml_dom_attr_get_name ((GXmlDomAttr*) price);
#line 75 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp83_ = _tmp82_;
#line 75 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp84_ = _tmp83_;
#line 75 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp84_, "price") == 0, "price.name == \"price\"");
#line 75 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp84_);
#line 76 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp85_ = gxml_gnode_get_namespaces ((GXmlGNode*) price);
#line 76 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp86_ = _tmp85_;
#line 76 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp87_ = _tmp86_;
#line 76 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (_tmp87_ != NULL, "price.namespaces != null");
#line 76 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp87_);
#line 77 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp88_ = gxml_gnode_get_namespaces ((GXmlGNode*) price);
#line 77 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp89_ = _tmp88_;
#line 77 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp90_ = _tmp89_;
#line 77 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp91_ = gee_collection_get_size ((GeeCollection*) _tmp90_);
#line 77 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp92_ = _tmp91_;
#line 77 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (_tmp92_ == 0, "price.namespaces.size == 0");
#line 77 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp90_);
#line 51 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (price);
#line 51 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (shell);
#line 51 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (core);
#line 51 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (node);
#line 51 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (root);
#line 51 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (doc);
#line 868 "GAttributeTest.c"
	}
	goto __finally174;
	__catch174_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp93_ = NULL;
		gchar* _tmp94_ = NULL;
		gchar* _tmp95_ = NULL;
#line 51 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		e = _inner_error_;
#line 51 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_inner_error_ = NULL;
#line 79 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp93_ = e->message;
#line 79 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp94_ = g_strconcat ("ERROR: ", _tmp93_, NULL);
#line 79 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp95_ = _tmp94_;
#line 79 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_test_message ("%s", _tmp95_);
#line 79 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp95_);
#line 80 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_assert_not_reached ();
#line 51 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_error_free0 (e);
#line 895 "GAttributeTest.c"
	}
	__finally174:
#line 51 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 51 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 51 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_clear_error (&_inner_error_);
#line 51 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		return;
#line 906 "GAttributeTest.c"
	}
}


static void ___lambda188__gtest_func (void) {
#line 50 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	__lambda188_ ();
#line 914 "GAttributeTest.c"
}


static void __lambda189_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGAttribute* nspshell = NULL;
		GXmlNode* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		GeeBidirList* _tmp4_ = NULL;
		GeeBidirList* _tmp5_ = NULL;
		GeeBidirList* _tmp6_ = NULL;
		gpointer _tmp7_ = NULL;
		GXmlGElement* _tmp8_ = NULL;
		GXmlNode* _tmp9_ = NULL;
		GXmlGAttribute* _tmp10_ = NULL;
		GXmlGAttribute* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		GXmlNamespace* _tmp15_ = NULL;
		GXmlNamespace* _tmp16_ = NULL;
		GXmlNamespace* _tmp17_ = NULL;
		GXmlNamespace* _tmp18_ = NULL;
		GXmlNamespace* _tmp19_ = NULL;
		GXmlNamespace* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		GXmlNamespace* _tmp24_ = NULL;
		GXmlNamespace* _tmp25_ = NULL;
		GXmlNamespace* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		GXmlGAttribute* nspshell2 = NULL;
		GXmlNode* _tmp33_ = NULL;
		GXmlNode* _tmp34_ = NULL;
		GXmlNode* _tmp35_ = NULL;
		GeeBidirList* _tmp36_ = NULL;
		GeeBidirList* _tmp37_ = NULL;
		GeeBidirList* _tmp38_ = NULL;
		gpointer _tmp39_ = NULL;
		GXmlNode* _tmp40_ = NULL;
		GeeMap* _tmp41_ = NULL;
		GeeMap* _tmp42_ = NULL;
		GeeMap* _tmp43_ = NULL;
		gpointer _tmp44_ = NULL;
		GXmlNode* _tmp45_ = NULL;
		GXmlGAttribute* _tmp46_ = NULL;
		GXmlGAttribute* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		GXmlNamespace* _tmp51_ = NULL;
		GXmlNamespace* _tmp52_ = NULL;
		GXmlNamespace* _tmp53_ = NULL;
		GXmlNamespace* _tmp54_ = NULL;
		GXmlNamespace* _tmp55_ = NULL;
		GXmlNamespace* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		gchar* _tmp59_ = NULL;
		GXmlNamespace* _tmp60_ = NULL;
		GXmlNamespace* _tmp61_ = NULL;
		GXmlNamespace* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
		gchar* _tmp65_ = NULL;
		gchar* _tmp66_ = NULL;
		gchar* _tmp67_ = NULL;
		gchar* _tmp68_ = NULL;
		GXmlGAttribute* shell = NULL;
		GXmlNode* _tmp69_ = NULL;
		GXmlNode* _tmp70_ = NULL;
		GXmlNode* _tmp71_ = NULL;
		GeeBidirList* _tmp72_ = NULL;
		GeeBidirList* _tmp73_ = NULL;
		GeeBidirList* _tmp74_ = NULL;
		gpointer _tmp75_ = NULL;
		GXmlGElement* _tmp76_ = NULL;
		GXmlNode* _tmp77_ = NULL;
		GXmlGAttribute* _tmp78_ = NULL;
		GXmlGAttribute* _tmp79_ = NULL;
		gchar* _tmp80_ = NULL;
		gchar* _tmp81_ = NULL;
		gchar* _tmp82_ = NULL;
		GXmlNamespace* _tmp83_ = NULL;
		GXmlNamespace* _tmp84_ = NULL;
		GXmlNamespace* _tmp85_ = NULL;
		gchar* _tmp86_ = NULL;
		gchar* _tmp87_ = NULL;
		gchar* _tmp88_ = NULL;
		GXmlGAttribute* shell2 = NULL;
		GXmlNode* _tmp89_ = NULL;
		GXmlNode* _tmp90_ = NULL;
		GXmlNode* _tmp91_ = NULL;
		GeeBidirList* _tmp92_ = NULL;
		GeeBidirList* _tmp93_ = NULL;
		GeeBidirList* _tmp94_ = NULL;
		gpointer _tmp95_ = NULL;
		GXmlNode* _tmp96_ = NULL;
		GeeMap* _tmp97_ = NULL;
		GeeMap* _tmp98_ = NULL;
		GeeMap* _tmp99_ = NULL;
		gpointer _tmp100_ = NULL;
		GXmlNode* _tmp101_ = NULL;
		GXmlGAttribute* _tmp102_ = NULL;
		GXmlGAttribute* _tmp103_ = NULL;
		gchar* _tmp104_ = NULL;
		gchar* _tmp105_ = NULL;
		gchar* _tmp106_ = NULL;
		GXmlNamespace* _tmp107_ = NULL;
		GXmlNamespace* _tmp108_ = NULL;
		GXmlNamespace* _tmp109_ = NULL;
		gchar* _tmp110_ = NULL;
		gchar* _tmp111_ = NULL;
		gchar* _tmp112_ = NULL;
#line 85 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<Wands xmlns=\"http://gxml.org/\" xmlns:wands=\"http://mom.co.uk/wands" \
"\"><Wand price=\"43.56\" wands:core=\"dragon heart cord\" wands:shell=" \
"\"oak\" cshell=\"NoNs\"/></Wands>", 0, &_inner_error_);
#line 85 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		doc = _tmp0_;
#line 85 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1045 "GAttributeTest.c"
			goto __catch175_g_error;
		}
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp1_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp2_ = _tmp1_;
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp3_ = _tmp2_;
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp4_ = gxml_node_get_children_nodes (_tmp3_);
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp5_ = _tmp4_;
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp6_ = _tmp5_;
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp7_ = gee_list_get ((GeeList*) _tmp6_, 0);
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp8_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlNode*) _tmp7_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp9_ = gxml_element_get_attr ((GXmlElement*) _tmp8_, "wands:shell");
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_GATTRIBUTE) ? ((GXmlGAttribute*) _tmp9_) : NULL;
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		if (_tmp10_ == NULL) {
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
			_g_object_unref0 (_tmp9_);
#line 1072 "GAttributeTest.c"
		}
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp11_ = _tmp10_;
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp8_);
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp6_);
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp3_);
#line 87 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		nspshell = _tmp11_;
#line 88 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (nspshell != NULL, "nspshell != null");
#line 89 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp12_ = gxml_dom_attr_get_name ((GXmlDomAttr*) nspshell);
#line 89 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp13_ = _tmp12_;
#line 89 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp14_ = _tmp13_;
#line 89 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp14_, "shell") == 0, "nspshell.name == \"shell\"");
#line 89 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp14_);
#line 90 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp15_ = gxml_attribute_get_namespace ((GXmlAttribute*) nspshell);
#line 90 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp16_ = _tmp15_;
#line 90 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp17_ = _tmp16_;
#line 90 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (_tmp17_ != NULL, "nspshell.namespace != null");
#line 90 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp17_);
#line 91 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp18_ = gxml_attribute_get_namespace ((GXmlAttribute*) nspshell);
#line 91 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp19_ = _tmp18_;
#line 91 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp20_ = _tmp19_;
#line 91 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp21_ = gxml_namespace_get_prefix (_tmp20_);
#line 91 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp22_ = _tmp21_;
#line 91 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp23_ = _tmp22_;
#line 91 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp23_, "wands") == 0, "nspshell.namespace.prefix == \"wands\"");
#line 91 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp23_);
#line 91 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp20_);
#line 92 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp24_ = gxml_attribute_get_namespace ((GXmlAttribute*) nspshell);
#line 92 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp25_ = _tmp24_;
#line 92 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp26_ = _tmp25_;
#line 92 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp27_ = gxml_namespace_get_uri (_tmp26_);
#line 92 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp28_ = _tmp27_;
#line 92 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp29_ = _tmp28_;
#line 92 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, "http://mom.co.uk/wands") == 0, "nspshell.namespace.uri == \"http://mom.co.uk/wands\"");
#line 92 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp29_);
#line 92 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp26_);
#line 93 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp30_ = gxml_dom_attr_get_value ((GXmlDomAttr*) nspshell);
#line 93 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp31_ = _tmp30_;
#line 93 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp32_ = _tmp31_;
#line 93 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp32_, "oak") == 0, "nspshell.value == \"oak\"");
#line 93 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp32_);
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp33_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp34_ = _tmp33_;
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp35_ = _tmp34_;
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp36_ = gxml_node_get_children_nodes (_tmp35_);
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp37_ = _tmp36_;
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp38_ = _tmp37_;
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp39_ = gee_list_get ((GeeList*) _tmp38_, 0);
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp40_ = (GXmlNode*) _tmp39_;
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp41_ = gxml_node_get_attrs (_tmp40_);
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp42_ = _tmp41_;
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp43_ = _tmp42_;
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp44_ = gee_map_get (_tmp43_, "wands:shell");
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp45_ = (GXmlNode*) _tmp44_;
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp46_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, GXML_TYPE_GATTRIBUTE) ? ((GXmlGAttribute*) _tmp45_) : NULL;
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		if (_tmp46_ == NULL) {
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
			_g_object_unref0 (_tmp45_);
#line 1184 "GAttributeTest.c"
		}
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp47_ = _tmp46_;
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp43_);
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp40_);
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp38_);
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp35_);
#line 95 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		nspshell2 = _tmp47_;
#line 96 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (nspshell2 != NULL, "nspshell2 != null");
#line 97 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp48_ = gxml_dom_attr_get_name ((GXmlDomAttr*) nspshell2);
#line 97 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp49_ = _tmp48_;
#line 97 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp50_ = _tmp49_;
#line 97 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp50_, "shell") == 0, "nspshell2.name == \"shell\"");
#line 97 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp50_);
#line 98 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp51_ = gxml_attribute_get_namespace ((GXmlAttribute*) nspshell2);
#line 98 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp52_ = _tmp51_;
#line 98 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp53_ = _tmp52_;
#line 98 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (_tmp53_ != NULL, "nspshell2.namespace != null");
#line 98 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp53_);
#line 99 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp54_ = gxml_attribute_get_namespace ((GXmlAttribute*) nspshell2);
#line 99 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp55_ = _tmp54_;
#line 99 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp56_ = _tmp55_;
#line 99 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp57_ = gxml_namespace_get_prefix (_tmp56_);
#line 99 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp58_ = _tmp57_;
#line 99 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp59_ = _tmp58_;
#line 99 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp59_, "wands") == 0, "nspshell2.namespace.prefix == \"wands\"");
#line 99 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp59_);
#line 99 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp56_);
#line 100 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp60_ = gxml_attribute_get_namespace ((GXmlAttribute*) nspshell2);
#line 100 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp61_ = _tmp60_;
#line 100 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp62_ = _tmp61_;
#line 100 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp63_ = gxml_namespace_get_uri (_tmp62_);
#line 100 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp64_ = _tmp63_;
#line 100 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp65_ = _tmp64_;
#line 100 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp65_, "http://mom.co.uk/wands") == 0, "nspshell2.namespace.uri == \"http://mom.co.uk/wands\"");
#line 100 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp65_);
#line 100 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp62_);
#line 101 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp66_ = gxml_dom_attr_get_value ((GXmlDomAttr*) nspshell2);
#line 101 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp67_ = _tmp66_;
#line 101 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp68_ = _tmp67_;
#line 101 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp68_, "oak") == 0, "nspshell2.value == \"oak\"");
#line 101 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp68_);
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp69_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp70_ = _tmp69_;
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp71_ = _tmp70_;
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp72_ = gxml_node_get_children_nodes (_tmp71_);
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp73_ = _tmp72_;
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp74_ = _tmp73_;
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp75_ = gee_list_get ((GeeList*) _tmp74_, 0);
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp76_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlNode*) _tmp75_, GXML_TYPE_GELEMENT, GXmlGElement);
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp77_ = gxml_element_get_attr ((GXmlElement*) _tmp76_, "cshell");
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp78_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp77_, GXML_TYPE_GATTRIBUTE) ? ((GXmlGAttribute*) _tmp77_) : NULL;
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		if (_tmp78_ == NULL) {
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
			_g_object_unref0 (_tmp77_);
#line 1290 "GAttributeTest.c"
		}
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp79_ = _tmp78_;
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp76_);
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp74_);
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp71_);
#line 103 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		shell = _tmp79_;
#line 104 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (shell != NULL, "shell != null");
#line 105 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (shell, GXML_TYPE_ATTRIBUTE), "shell is Attribute");
#line 106 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp80_ = gxml_dom_attr_get_name ((GXmlDomAttr*) shell);
#line 106 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp81_ = _tmp80_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp82_ = _tmp81_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp82_, "cshell") == 0, "shell.name == \"cshell\"");
#line 106 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp82_);
#line 107 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp83_ = gxml_attribute_get_namespace ((GXmlAttribute*) shell);
#line 107 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp84_ = _tmp83_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp85_ = _tmp84_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (_tmp85_ == NULL, "shell.namespace == null");
#line 107 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp85_);
#line 108 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp86_ = gxml_dom_attr_get_value ((GXmlDomAttr*) shell);
#line 108 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp87_ = _tmp86_;
#line 108 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp88_ = _tmp87_;
#line 108 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp88_, "NoNs") == 0, "shell.value == \"NoNs\"");
#line 108 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp88_);
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp89_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp90_ = _tmp89_;
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp91_ = _tmp90_;
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp92_ = gxml_node_get_children_nodes (_tmp91_);
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp93_ = _tmp92_;
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp94_ = _tmp93_;
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp95_ = gee_list_get ((GeeList*) _tmp94_, 0);
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp96_ = (GXmlNode*) _tmp95_;
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp97_ = gxml_node_get_attrs (_tmp96_);
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp98_ = _tmp97_;
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp99_ = _tmp98_;
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp100_ = gee_map_get (_tmp99_, "cshell");
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp101_ = (GXmlNode*) _tmp100_;
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp102_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp101_, GXML_TYPE_GATTRIBUTE) ? ((GXmlGAttribute*) _tmp101_) : NULL;
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		if (_tmp102_ == NULL) {
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
			_g_object_unref0 (_tmp101_);
#line 1368 "GAttributeTest.c"
		}
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp103_ = _tmp102_;
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp99_);
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp96_);
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp94_);
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp91_);
#line 110 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		shell2 = _tmp103_;
#line 111 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (shell2 != NULL, "shell2 != null");
#line 112 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp104_ = gxml_dom_attr_get_name ((GXmlDomAttr*) shell2);
#line 112 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp105_ = _tmp104_;
#line 112 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp106_ = _tmp105_;
#line 112 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp106_, "cshell") == 0, "shell2.name == \"cshell\"");
#line 112 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp106_);
#line 113 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp107_ = gxml_attribute_get_namespace ((GXmlAttribute*) shell2);
#line 113 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp108_ = _tmp107_;
#line 113 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp109_ = _tmp108_;
#line 113 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (_tmp109_ == NULL, "shell2.namespace == null");
#line 113 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp109_);
#line 114 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp110_ = gxml_dom_attr_get_value ((GXmlDomAttr*) shell2);
#line 114 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp111_ = _tmp110_;
#line 114 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp112_ = _tmp111_;
#line 114 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp112_, "NoNs") == 0, "shell2.value == \"NoNs\"");
#line 114 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp112_);
#line 84 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (shell2);
#line 84 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (shell);
#line 84 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (nspshell2);
#line 84 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (nspshell);
#line 84 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (doc);
#line 1424 "GAttributeTest.c"
	}
	goto __finally175;
	__catch175_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp113_ = NULL;
		gchar* _tmp114_ = NULL;
		gchar* _tmp115_ = NULL;
#line 84 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		e = _inner_error_;
#line 84 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_inner_error_ = NULL;
#line 116 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp113_ = e->message;
#line 116 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp114_ = g_strconcat ("ERROR: ", _tmp113_, NULL);
#line 116 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp115_ = _tmp114_;
#line 116 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_test_message ("%s", _tmp115_);
#line 116 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp115_);
#line 117 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_assert_not_reached ();
#line 84 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_error_free0 (e);
#line 1451 "GAttributeTest.c"
	}
	__finally175:
#line 84 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 84 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 84 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_clear_error (&_inner_error_);
#line 84 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		return;
#line 1462 "GAttributeTest.c"
	}
}


static void ___lambda189__gtest_func (void) {
#line 83 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	__lambda189_ ();
#line 1470 "GAttributeTest.c"
}


static void __lambda190_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlNode* e = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		GeeBidirList* _tmp4_ = NULL;
		GeeBidirList* _tmp5_ = NULL;
		GeeBidirList* _tmp6_ = NULL;
		GXmlNode* _tmp7_ = NULL;
		GXmlNode* c = NULL;
		GXmlGDocument* _tmp8_ = NULL;
		GXmlNode* _tmp9_ = NULL;
		GXmlNode* _tmp10_ = NULL;
		GeeBidirList* _tmp11_ = NULL;
		GeeBidirList* _tmp12_ = NULL;
		GeeBidirList* _tmp13_ = NULL;
		GXmlNode* _tmp14_ = NULL;
		GXmlNode* _tmp15_ = NULL;
		GXmlGDocument* _tmp16_ = NULL;
		GXmlNode* _tmp17_ = NULL;
		GXmlNode* _tmp18_ = NULL;
		GXmlNode* _tmp19_ = NULL;
		GXmlGDocument* _tmp20_ = NULL;
		GXmlNode* _tmp21_ = NULL;
		GXmlNode* _tmp22_ = NULL;
		GXmlNode* _tmp23_ = NULL;
		GeeMap* _tmp24_ = NULL;
		GeeMap* _tmp25_ = NULL;
		GeeMap* _tmp26_ = NULL;
		gpointer _tmp27_ = NULL;
		GXmlNode* _tmp28_ = NULL;
		GXmlGDocument* _tmp29_ = NULL;
		GXmlNode* _tmp30_ = NULL;
		GXmlNode* _tmp31_ = NULL;
		GXmlNode* _tmp32_ = NULL;
		GeeMap* _tmp33_ = NULL;
		GeeMap* _tmp34_ = NULL;
		GeeMap* _tmp35_ = NULL;
		gpointer _tmp36_ = NULL;
		GXmlNode* _tmp37_ = NULL;
		GXmlNode* _tmp38_ = NULL;
		GXmlNode* _tmp39_ = NULL;
		GXmlNode* _tmp40_ = NULL;
		GXmlGDocument* _tmp41_ = NULL;
		GXmlNode* _tmp42_ = NULL;
		GXmlNode* _tmp43_ = NULL;
		GXmlNode* _tmp44_ = NULL;
		GeeMap* _tmp45_ = NULL;
		GeeMap* _tmp46_ = NULL;
		GeeMap* _tmp47_ = NULL;
		gpointer _tmp48_ = NULL;
		GXmlNode* _tmp49_ = NULL;
		GXmlNode* _tmp50_ = NULL;
		GXmlNode* _tmp51_ = NULL;
		GXmlNode* _tmp52_ = NULL;
		gchar* _tmp53_ = NULL;
		gchar* _tmp54_ = NULL;
		gchar* _tmp55_ = NULL;
#line 122 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 122 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		doc = _tmp0_;
#line 123 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp1_ = doc;
#line 123 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp2_ = gxml_document_create_element ((GXmlDocument*) _tmp1_, "root", &_inner_error_);
#line 123 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		e = _tmp2_;
#line 123 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 123 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
			_g_object_unref0 (doc);
#line 1550 "GAttributeTest.c"
			goto __catch176_g_error;
		}
#line 124 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp3_ = doc;
#line 124 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp4_ = gxml_gnode_get_children_nodes ((GXmlGNode*) _tmp3_);
#line 124 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp5_ = _tmp4_;
#line 124 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp6_ = _tmp5_;
#line 124 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp7_ = e;
#line 124 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		gee_collection_add ((GeeCollection*) _tmp6_, _tmp7_);
#line 124 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp6_);
#line 125 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp8_ = doc;
#line 125 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp9_ = gxml_document_create_element ((GXmlDocument*) _tmp8_, "child", &_inner_error_);
#line 125 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		c = _tmp9_;
#line 125 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 125 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
			_g_object_unref0 (e);
#line 125 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
			_g_object_unref0 (doc);
#line 1579 "GAttributeTest.c"
			goto __catch176_g_error;
		}
#line 126 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp10_ = e;
#line 126 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp11_ = gxml_node_get_children_nodes (_tmp10_);
#line 126 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp12_ = _tmp11_;
#line 126 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp13_ = _tmp12_;
#line 126 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp14_ = c;
#line 126 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		gee_collection_add ((GeeCollection*) _tmp13_, _tmp14_);
#line 126 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp13_);
#line 127 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp15_ = e;
#line 127 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		gxml_element_set_attr (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp15_) : NULL, "attr", "val");
#line 128 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp16_ = doc;
#line 128 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp17_ = gxml_document_get_root ((GXmlDocument*) _tmp16_);
#line 128 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp18_ = _tmp17_;
#line 128 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp19_ = _tmp18_;
#line 128 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (_tmp19_ != NULL, "doc.root != null");
#line 128 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp19_);
#line 129 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp20_ = doc;
#line 129 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp21_ = gxml_document_get_root ((GXmlDocument*) _tmp20_);
#line 129 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp22_ = _tmp21_;
#line 129 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp23_ = _tmp22_;
#line 129 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp24_ = gxml_node_get_attrs (_tmp23_);
#line 129 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp25_ = _tmp24_;
#line 129 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp26_ = _tmp25_;
#line 129 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp27_ = gee_map_get (_tmp26_, "attr");
#line 129 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp28_ = (GXmlNode*) _tmp27_;
#line 129 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (_tmp28_ != NULL, "doc.root.attrs[\"attr\"] != null");
#line 129 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp28_);
#line 129 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp26_);
#line 129 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp23_);
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp29_ = doc;
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp30_ = gxml_document_get_root ((GXmlDocument*) _tmp29_);
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp31_ = _tmp30_;
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp32_ = _tmp31_;
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp33_ = gxml_node_get_attrs (_tmp32_);
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp34_ = _tmp33_;
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp35_ = _tmp34_;
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp36_ = gee_map_get (_tmp35_, "attr");
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp37_ = (GXmlNode*) _tmp36_;
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp38_ = gxml_node_get_parent (_tmp37_);
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp39_ = _tmp38_;
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp40_ = _tmp39_;
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (_tmp40_ != NULL, "doc.root.attrs[\"attr\"].parent != null");
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp40_);
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp37_);
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp35_);
#line 130 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp32_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp41_ = doc;
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp42_ = gxml_document_get_root ((GXmlDocument*) _tmp41_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp43_ = _tmp42_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp44_ = _tmp43_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp45_ = gxml_node_get_attrs (_tmp44_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp46_ = _tmp45_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp47_ = _tmp46_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp48_ = gee_map_get (_tmp47_, "attr");
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp49_ = (GXmlNode*) _tmp48_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp50_ = gxml_node_get_parent (_tmp49_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp51_ = _tmp50_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp52_ = _tmp51_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp53_ = gxml_node_get_name (_tmp52_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp54_ = _tmp53_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp55_ = _tmp54_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_vala_assert (g_strcmp0 (_tmp55_, "root") == 0, "doc.root.attrs[\"attr\"].parent.name == \"root\"");
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp55_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp52_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp49_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp47_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (_tmp44_);
#line 121 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (c);
#line 121 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (e);
#line 121 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_object_unref0 (doc);
#line 1720 "GAttributeTest.c"
	}
	goto __finally176;
	__catch176_g_error:
	{
		GError* e = NULL;
		GError* _tmp56_ = NULL;
		const gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		gchar* _tmp59_ = NULL;
#line 121 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		e = _inner_error_;
#line 121 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_inner_error_ = NULL;
#line 132 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp56_ = e;
#line 132 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp57_ = _tmp56_->message;
#line 132 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp58_ = g_strconcat ("ERROR: ", _tmp57_, NULL);
#line 132 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_tmp59_ = _tmp58_;
#line 132 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_message ("GAttributeTest.vala:132: %s", _tmp59_);
#line 132 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_free0 (_tmp59_);
#line 121 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		_g_error_free0 (e);
#line 1748 "GAttributeTest.c"
	}
	__finally176:
#line 121 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 121 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 121 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		g_clear_error (&_inner_error_);
#line 121 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
		return;
#line 1759 "GAttributeTest.c"
	}
}


static void ___lambda190__gtest_func (void) {
#line 120 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	__lambda190_ ();
#line 1767 "GAttributeTest.c"
}


void gattribute_test_add_tests (void) {
#line 28 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	g_test_add_func ("/gxml/gattribute/value", ___lambda187__gtest_func);
#line 50 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	g_test_add_func ("/gxml/gattribute/namespace", ___lambda188__gtest_func);
#line 83 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	g_test_add_func ("/gxml/gattribute/namespace_value", ___lambda189__gtest_func);
#line 120 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	g_test_add_func ("/gxml/tw-attribute/parent", ___lambda190__gtest_func);
#line 1780 "GAttributeTest.c"
}


GAttributeTest* gattribute_test_construct (GType object_type) {
	GAttributeTest* self = NULL;
#line 26 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	self = (GAttributeTest*) gxml_test_construct (object_type);
#line 26 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	return self;
#line 1790 "GAttributeTest.c"
}


GAttributeTest* gattribute_test_new (void) {
#line 26 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	return gattribute_test_construct (TYPE_GATTRIBUTE_TEST);
#line 1797 "GAttributeTest.c"
}


static void gattribute_test_class_init (GAttributeTestClass * klass) {
#line 26 "/home/despinosa/Proyectos/gxml/test/GAttributeTest.vala"
	gattribute_test_parent_class = g_type_class_peek_parent (klass);
#line 1804 "GAttributeTest.c"
}


static void gattribute_test_instance_init (GAttributeTest * self) {
}


GType gattribute_test_get_type (void) {
	static volatile gsize gattribute_test_type_id__volatile = 0;
	if (g_once_init_enter (&gattribute_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GAttributeTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gattribute_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GAttributeTest), 0, (GInstanceInitFunc) gattribute_test_instance_init, NULL };
		GType gattribute_test_type_id;
		gattribute_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GAttributeTest", &g_define_type_info, 0);
		g_once_init_leave (&gattribute_test_type_id__volatile, gattribute_test_type_id);
	}
	return gattribute_test_type_id__volatile;
}



